precision highp float;
varying highp vec2 vTextureCoord;
uniform sampler2D iChannel0;
uniform sampler2D iChannel1; // lookup texture
uniform float intensity;

//8x8 lut
const float matchLut = 8.0;

vec4 lookup(in vec4 textureColor){
    mediump float blueColor = textureColor.b * (pow(matchLut, 2.0)-1.0);
    mediump vec2 quad1;
    quad1.y = floor(floor(blueColor) / matchLut);
    quad1.x = floor(blueColor) - (quad1.y * matchLut);
    mediump vec2 quad2;
    quad2.y = floor(ceil(blueColor) / matchLut);
    quad2.x = ceil(blueColor) - (quad2.y * matchLut);
    highp vec2 texPos1;
    float dimen = pow(matchLut, 3.0);
    texPos1.x = (quad1.x *(1.0/matchLut)) + 0.5/(dimen)+ ((1.0/matchLut - 1.0/dimen) * textureColor.r);
    texPos1.y = (quad1.y *(1.0/matchLut)) + 0.5/(dimen) + ((1.0/matchLut - 1.0/dimen) * textureColor.g);
    highp vec2 texPos2;
    texPos2.x = (quad2.x *(1.0/matchLut)) + 0.5/(dimen) + ((1.0/matchLut - 1.0/dimen) * textureColor.r);
    texPos2.y = (quad2.y *(1.0/matchLut)) + 0.5/(dimen) + ((1.0/matchLut - 1.0/dimen) * textureColor.g);
    lowp vec4 newColor1 = texture2D(iChannel1, texPos1);
    lowp vec4 newColor2 = texture2D(iChannel1, texPos2);
    lowp vec4 newColor = mix(newColor1, newColor2, fract(blueColor));
    return newColor;
}

void main()
{
    lowp vec4 textureColor = texture2D(iChannel0, vTextureCoord);
    vec4 filteredColor = lookup(textureColor);
    gl_FragColor = mix(textureColor, vec4(filteredColor.rgb, textureColor.w), intensity);
}