precision highp float;

varying highp vec2 vTextureCoord;
uniform sampler2D iChannel0;
uniform sampler2D iChannel1;
uniform float progress;
uniform float shape;//0.0
uniform vec3 iResolution;

#define PI 3.14159265359
const int segments = 5;
const vec2 center = vec2(0.5, 0.5);// = vec2(0.5, 0.5);
const vec3 backColor = vec3(0.1, 0.1, 0.1);// = vec3(0.1, 0.1, 0.1);

vec4 getFromColor(vec2 uv) {
    return texture2D(iChannel0, vec2(uv.x, uv.y));
}

vec4 getToColor(vec2 uv) {
    return texture2D(iChannel1, vec2(uv.x, uv.y));
}

float inHeart (vec2 p, vec2 center, float size) {
    //p.y = 1.0 - p.y;
    if (size==0.0) return 0.0;
    vec2 o = (p-center)/(1.6*size);
    float a = o.x*o.x+o.y*o.y-0.3;
    return step(a*a*a, o.x*o.x*o.y*o.y*o.y);
}

vec4 transition (vec2 uv) {
    float ratio = iResolution.x / iResolution.y;
    vec2 vRatio = vec2(1.0, 1.0 / ratio);

    float radius = sqrt(8.0) * abs(progress - 0.5);
    float distance = length((uv - center) * vRatio);
    if (distance > radius) {
        return vec4(backColor, 1.0);
    } else {
        if (progress < 0.5) return getFromColor(uv);
        else return getToColor(uv);
    }
}

void main() {
    gl_FragColor = transition(vTextureCoord);
}
